%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
%   Copyright (C) 2007 MARTIN RUFLI
%   
%   Initially written by Martin Rufli and modified by Davide Scaramuzza
%   Adapted to the Kinect Toolbox by Daniel Herrera C.
%   
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
%   
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%   
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
%   USA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [corner_p]=click_ima_calib_rufli_k(kk,I,use_corner_find,wintx,winty,n_sq_x,n_sq_y,handles)
% kk=1;
% path_calibration_data='D:\Peta\doktorske\FEKT\program dizertace\kalibrace 06082013\jen nektere';
% I=imread([path_calibration_data '\calibration_data\001TOF_filter.png']);
% use_corner_find='true';
% wintx=5;
% winty=5;
% n_sq_x=4;
% n_sq_y=4;


%auto_path = [fileparts(mfilename('fullpath')) '/autoCornerFinder'];
auto_path = [pwd '\autoCornerFinder'];
map = gray(256);

if(size(I,3)==3)%%insert
    I = rgb2gray(I);%%insert
end

if(isequal(class(I),'uint8'))
  I = im2double(I);
end

fclose('all');
if exist([auto_path '/cToMatlab/cornerInfo.txt'],'file')
    delete([auto_path '/cToMatlab/cornerInfo.txt']);
end
if exist([auto_path '/cToMatlab/cornersX.txt'],'file')
    delete([auto_path '/cToMatlab/cornersX.txt']);
end
if exist([auto_path '/cToMatlab/cornersY.txt'],'file')
    delete([auto_path '/cToMatlab/cornersY.txt']);
end
if exist([auto_path '/cToMatlab/error.txt'],'file')
    delete([auto_path '/cToMatlab/error.txt']);
end

%INITIALIZATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fprintf(1,'\nProcessing image %d...\n',kk);

% if use_corner_find
%     fprintf(1,'Using (wintx,winty)=(%d,%d) - Window size = %dx%d\n',wintx,winty,2*wintx+1,2*winty+1);
% end


%EXTERNAL CORNER FINDING ALGORITHM CALL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%kk jumps over empty image slots (i.e. kk = 1->2->4->5, if image 3 was not 
%loaded), whereas l(j,1).name does not. Therefore account for it!
% if kk == indices( ima_numbers(1) );
%     iter_r = ima_numbers(1);
%     iter_rr= 2;
% else
%     iter_r = ima_numbers(iter_rr);
%     iter_rr= iter_rr + 1;
% end

%Tell the automatic corner extractor, which image file to process
% fid = fopen([auto_path '/pictures.txt'],'w');
% fprintf(fid,'../%s',l(kk).name);
% fclose(fid);
% iter_r = iter_r + 1;    %!!!iter_r is defined in "click_calib.m"!!!

%Save image for external program. 
%'temp.jpg' should always be in pictures.txt
imwrite(I,[auto_path '/temp.jpg']);

%Call the automatic corner extraction algorithm
%Width and height in the algorithm are defined differently than
%in this toolbox: Its the number of inernal corners instead of 
%internal quadrangles.
%-m specifies the number of corners the algorithm has to find, before it
%terminates
%If callback = -1   ->An error occured, automatic corner finding is aborted
%            =  0   ->Not enough corners have been found, add some manually
%            =  1   ->Enough corners have been found for calibration


%Visualization turned OFF
old_dir = cd();
cd(auto_path);

callString = (['FindCorners.exe -w ' num2str(n_sq_x+1) ' -h ' num2str(n_sq_y+1) ' -m ' num2str((n_sq_x+1) * (n_sq_y+1)) ' pictures.txt']);

if ~ispc %if not Windows
    callString = ['./' callString];
end
%Visualization turned ON
%callString = (['cd autoCornerFinder & FindCornersVisual.exe -w ' num2str(n_sq_x+1) ' -h ' num2str(n_sq_y+1) ' -m ' num2str((n_sq_x+1) * (n_sq_y+1)) ' pictures.txt']);

%Visualization turned ON and Saving of the images turned ON
%WARNING: Does somehow not work under Windows 2000...
%callString = (['cd autoCornerFinder & FindCornersVisualSave.exe -w ' num2str(n_sq_x+1) ' -h ' num2str(n_sq_y+1) ' -m ' num2str((n_sq_x+1) * (n_sq_y+1)) ' pictures.txt']);

callBack   = dos(callString);
cd(old_dir);

%Do error checking
if callBack == -1
    %Display the error message

    disp('During corner finding an error occured:')
    filename = [auto_path '/cToMatlab/error.txt'];
    fid = fopen(filename, 'r');
    line = fgetl(fid);
    fclose(fid);
    disp(line)
%     disp('Please restart "Extract grid corners" or remove this image from the input dataset.');
    disp('Use manual selection instead.');
    %fprintf(1,'Press ENTER to continue.\n');
    %pause;
    corner_x = [];
    corner_p = [];
    return;
end

%Open the corner size information file
filename = [auto_path '/cToMatlab/cornerInfo.txt'];
fid = fopen(filename, 'r');
cornerInfo = fscanf(fid, '%g %g', [1 2]);   
fclose(fid);

%Open the files with the found corners
filename = [auto_path '/cToMatlab/cornersX.txt'];
fid = fopen(filename, 'r');
cornersX = fscanf(fid, '%g %g', [cornerInfo(2) cornerInfo(1)]);
cornersX = cornersX';
fclose(fid);

filename = [auto_path '/cToMatlab/cornersY.txt'];
fid = fopen(filename, 'r');
cornersY = fscanf(fid, '%g %g', [cornerInfo(2) cornerInfo(1)]);
cornersY = cornersY';
fclose(fid);


%VARIABLE DEFINITIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
numCorners = (n_sq_x+1)*(n_sq_y+1);
numCornerThreshold = (n_sq_x+1)*(n_sq_y+1);
numOfFoundCorners = 0;
cornerNumber = 0;
cornersNumbering = -1*ones(cornerInfo(1),cornerInfo(2));
startingCorner = [];
nextFoundCorner = [-1,-1];
deltaCols = 0;
startingCornerSet = false;
%Index of the corner with the smallest index
min_i = [];
min_j = [];
%Used for image zoom in
[size1, size2] = size(I);
min_x = max(size1, size2) + 1;
max_x = 0;
min_y = max(size1, size2) + 1;
max_y = 0;

%figure(1);
%hold off;


%INPUT CORNER VALUE AND MATRIX SIZE ADAPTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%If there are entire rows of zeros at the end of the file, this means that
%the cornerfinder is not entirely shure about the location of the board.
%Then eventually additional corners are needed in the front.
[iSave, dummy] = find(cornersX >= 0);
iSave = max(iSave);
%Add at least one row! This is because the columns are maybe ambiguous, 
%and then we don't know whether they belong to the current row or to the
%next one...
if (cornerInfo(1) - iSave >= 0)
    cornersX = [-1* ones(cornerInfo(1) - iSave + 1, cornerInfo(2)); cornersX];
    cornersY = [-1* ones(cornerInfo(1) - iSave + 1, cornerInfo(2)); cornersY];
end
[rows, cols] = size(cornersX); 

%Add one pixel to every non "-1" value, since Matlab starts numbering
%at one, whereas c++ starts at zero.
flagStart = true;
for i = 1:1:rows
    for j = 1:1:cols
        %Define the starting corner as the first found corner
        %which has a neighbor corner which was also found
        if j ~= cols && flagStart == true
            if cornersX(i,j) >= 0 && cornersX(i,j+1) >= 0
                startingCorner = [i,j];
                flagStart = false;
            end
        end
        if cornersX(i,j) >= 0
            cornersX(i,j) = cornersX(i,j) + 1;
            %Count the number of found corners
            numOfFoundCorners = numOfFoundCorners + 1;
            %Determine the minimal and maximal cordinates of all
            %found corners. ->Needed further down
            if cornersX(i,j) > max_x
                max_x = cornersX(i,j);
            end
            if cornersX(i,j) < min_x
                min_x = cornersX(i,j);
            end
        end
        if cornersY(i,j) >= 0
            cornersY(i,j) = cornersY(i,j) + 1;
            if cornersY(i,j) > max_y
                max_y = cornersY(i,j);
            end
            if cornersY(i,j) < min_y
                min_y = cornersY(i,j);
            end
        end
    end
end


%PREPARATIONS FOR PROPER PLOT ZOOM-IN
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
min_x = min_x - (max_x - min_x)*(1 - numOfFoundCorners/numCorners + 0.2);
max_x = max_x + (max_x - min_x)*(1 - numOfFoundCorners/numCorners + 0.2);
min_y = min_y - (max_y - min_y)*(1 - numOfFoundCorners/numCorners + 0.2);
max_y = max_y + (max_y - min_y)*(1 - numOfFoundCorners/numCorners + 0.2);

min_x = max(min_x,0);
max_x = min(max_x,size2);
min_y = max(min_y,0);
max_y = min(max_y,size1);


%ORIENTATION AMBIGUITY?
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Decide whether the position and orientation of the checkerboard
%can be unambiguously determined
% if min((n_sq_y+1), (n_sq_x+1)) ~= min(cornerInfo(1),cornerInfo(2))
%     if flagStart == true
%         %DISPLAY AN ERROR AND RETURN
%     end
%     %There is some ambiguity, get rid of it
%     %figure(1);
%     imshow(I,'Parent',handles.axes1);
%     colormap(map);
%     set(1,'color',[1 1 1]);
%     title({['Image ' num2str(kk)]});
%     h = get(gca, 'title');
%     set(h, 'FontWeight', 'bold')
%     axis([min_x max_x min_y max_y]);
% 
% 
%     %figure(1); hold on;
%     i = startingCorner(1)
%     j = startingCorner(2)
%     %Plot the starting corner and its neighbor
%     plot(handles.axes1, cornersX(i,j),cornersY(i,j),'+','color','red','linewidth',2);
%     plot(handles.axes1, cornersX(i,j+1),cornersY(i,j+1),'+','color','red','linewidth',2);
%     text( cornersX(i,j)+3,cornersY(i,j)+3,num2str(0) )
%     text( cornersX(i,j+1)+3,cornersY(i,j+1)+3,num2str(1) )
%     set(findobj('type', 'text'), 'color', 'red'); 
%     %hold off;
%       
%     %Get user input on behalf of the board orientation
%     numCornersDirZeroOne = input(['The automatic corner finder was not able to decide how the pattern is oriented. Please indicate the number of corners in direction of corners [0 -> 1]: ']);
%     %We look in row direction
%     deltaCols = cornerInfo(2) - numCornersDirZeroOne;                 
% end


%DRAW AND NUMBER FOUND CORNERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Draw the found corners onto the image and number them 
%Define the first encountered found corner as number "zero"
PlotXxiX = [];
PlotXxiY = [];
PlotCornersX = [];
PlotCornersY = [];
PlotCornerNumber = [];

for i = 1:1:rows
    for j = 1:1:(cols-deltaCols)
        if cornersX(i,j) ~= -1
            %Save for plotting later
            PlotCornersX = [PlotCornersX,cornersX(i,j)];
            PlotCornersY = [PlotCornersY,cornersY(i,j)];
            PlotCornerNumber = [PlotCornerNumber, cornerNumber+1];
            if use_corner_find
                %Apply the corner finder
                [xxi] = cornerfinder([cornersX(i,j);cornersY(i,j)],I,winty,wintx);
                %Save for plotting later
                PlotXxiX = [PlotXxiX,xxi(1)];
                PlotXxiY = [PlotXxiY,xxi(2)];
                
                %Replace initial
                cornersX(i,j) = xxi(1);
                cornersY(i,j) = xxi(2);
            end
            if cornerNumber == 0
                %Change starting corner to this one
                %Needed further down
                startingCorner = [i,j];
                startingCornerSet = true;
            end
        end
        if startingCornerSet == true
            cornerNumber = cornerNumber + 1;
        end
    end
end

% %figure(1);
% %hold off;
% imshow(I,'Parent',handles.axes1);
% %colormap(map);
% %set(1,'color',[1 1 1]);
% % title({['Image ' num2str(kk)]; [num2str(numOfFoundCorners) ' / ' num2str(numCorners) ' corner have been found.']; ['Red: initial detection. Blue: enhanced']; ['Press ENTER to continue.']});
% %title({['Image ' num2str(kk) '-' num2str(numOfFoundCorners) ' / ' num2str(numCorners) ' corner have been found. Red: initial detection. Blue: enhanced']});
% % h = get(gca, 'title');
% % set(h, 'FontWeight', 'bold')
% % axis([min_x max_x min_y max_y])
% 
% %Plot the original corners
% %hold on;
% plot(handles.axes1, PlotCornersX,PlotCornersY,'+','color','red','linewidth',2);
% if use_corner_find
%     %Plot the "corner finder enhanced" corners
%     plot( handles.axes1,PlotXxiX,PlotXxiY,'+','color','blue','linewidth',2);
% end

%text( PlotCornersX'+3,PlotCornersY'+3,num2str(PlotCornerNumber') )
%set(findobj('type', 'text'), 'color', 'red');             
%hold off
%drawnow;
% pause;

%ADD NEW CORNERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Only do this, if we still need to add some corners
if numCorners ~= numOfFoundCorners   
%   fprintf('Couldn''t locate all corners automatically for image %d. Use manual selection instead.\n',kk);
  %fprintf(1,'Press ENTER to continue.\n');
  %pause;
  corner_p = [];
  corner_x = [];
  return;

end

%If no negative corners were designated, then "min_i" and "min_j"
%are still empty
if isempty(min_i)
    min_i = startingCorner(1);
    min_j = startingCorner(2);
end


%SAVE CORNER INFORMATION IN 2 VECTORS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Save all corners in two arrays for further processing
%by other functions
x = [];
y = [];

%Start with the smallest found corner and then append the larger ones
iteration = 0;
while true
    %Iterators
    i = min_i + floor(iteration/(cols-deltaCols));
    j = mod( (min_j - 1 + iteration),cols-deltaCols ) + 1;
    iteration = iteration + 1;
    
    x = [x,cornersX(i,j)];
    y = [y,cornersY(i,j)];
    
    if(iteration >= numCorners | i > rows)
        break
    end
end



%    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Assign final outputs

% Yp_abs(:,:,kk) = x';
% Xp_abs(:,:,kk) = y';
z=length(x);
corner_p = [x-1;y-1;ones(1,z);PlotCornersX-1;PlotCornersY-1];

% Xi = ones(1,n_sq_y+1)'*(0:n_sq_x);
% Yi = (0:n_sq_y)'*ones(n_sq_x+1,1)';
% Zi = zeros(1,length(Xi(:)));
% corner_x = [Xi(:)';Yi(:)';Zi];

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % Visualize
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% if 0
%     %figure(1);
%     imshow(I,'Parent',handles.axes1);
%     colormap(map);
%     title({['Image ' num2str(kk) ' The corners have been renumbered in the right order. Press ENTER to continue or other to cancel.']});  
%     h = get(gca, 'title');
%     set(h, 'FontWeight', 'bold')
%     %hold on;
%     %Plot the corners
%     plot(handles.axes1, x,y,'+','color','red','linewidth',2);
%     %Plot the corresponding number
%     text( x'+3,y'+3,num2str(iNumber') )
%     set(findobj('type', 'text'), 'color', 'red');
%     axis([min_x max_x min_y max_y]);
% %     draw_axes(Xp_abs(:,:,kk), Yp_abs(:,:,kk),n_sq_y);
%     draw_axes(x', y',n_sq_y);
%     res=input('Use these corners ([]=yes, other=discard):','s');
%     if(~isempty(res))
%       corner_x = [];
%       corner_p = [];
%     end
%     %close(2);
% end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DELETE FILES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%We delete the interface files between Matlab and c++, in order to prevent
%reloading old data in case of some errors.
delete([auto_path '/cToMatlab/cornerInfo.txt']);
delete([auto_path '/cToMatlab/cornersX.txt']);
delete([auto_path '/cToMatlab/cornersY.txt']);
delete([auto_path '/cToMatlab/error.txt']);

%Return corners

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%END OF CODE
end