
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   compute_distance_correction
%   by Petra Kocmanova
%   last modified: 27.6.2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [results]=compute_distance_correction(handles)
% Load measured data and compute reggression model for distance correction
% of each pixel

folder_name=getappdata(handles.figure1,'folder_name');
DISTl=getappdata(handles.figure1,'DISTl');
DISTl=DISTl';

d=dir([folder_name '/*.mat']);
numfiles = length(d);

%Determination of image borders, that are used for calibration
ij=get(handles.uitable6,'Data');
iz1=ij(1,1);
iz2=ij(1,2);
jz1=ij(2,1);
jz2=ij(2,2);
nz=numfiles;

%Determination of model for calibration
model=get(handles.popupmenu1,'Value');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%progress dialog
d1 = com.mathworks.mlwidgets.dialog.ProgressBarDialog.createProgressBar...
    ('Distance calibration', []);
d1.setValue(0.05);                        % default = 0
d1.setProgressStatusLabel('Processing...');  % default = 'Please Wait'
d1.setSpinnerVisible(true);               % default = true
d1.setCircularProgressBar(false);         % default = false  (true means an indeterminate (looping) progress bar)
d1.setCancelButtonVisible(false);          % default = true
d1.setVisible(true);                      % default = false
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

DISTn=zeros(nz,((iz2-iz1+1)*(jz2-jz1+1)));
CONFn=zeros(nz,((iz2-iz1+1)*(jz2-jz1+1)));
%AMPLn=zeros(nz,((iz2-iz1+1)*(jz2-jz1+1)));

%Load measurement data
for n=1:numfiles;
    k=0;
    for i=iz1:iz2;
        for j=jz1:jz2;
            k=k+1;
            %run ([folder_name '/meas' num2str(n)]);
            load([folder_name '/meas' num2str(n) '.mat']);
            DISTn(n,k)=meas.DIST(i,j);
            CONFn(n,k)=meas.CONF(i,j);
            %AMPLn(n,k)=meas.AMPL(i,j);
            clear meas
        end
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %progress dialog
    d1.setValue(0.05+0.45*n/numfiles);
    d1.setProgressStatusLabel(['Processing...data loading (' int2str(n)...
        '/' int2str(numfiles) ')'] );
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
end

DIST=DISTn;
CONF=CONFn;
%AMPL=AMPLn;



%load TOF camera intrinsics parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
data=xlsread('Mutual_calibration_RESULTS','B2:B9');

fx=data(1,1);
fy=data(2,1);
f=(fx+fy)/2;
xp0=data(3,1);
yp0=data(4,1);
k1=data(5,1);
k2=data(6,1);
p1=data(7,1);
p2=data(8,1);
k3=0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xi=repmat((1:176)',1,144);
yi=repmat((1:144),176,1);

k=1;
Xi=zeros(1,(iz2-iz1+1)*(jz2-jz1+1));
Yi=zeros(1,(iz2-iz1+1)*(jz2-jz1+1));
I=zeros((iz2-iz1+1)*(jz2-jz1+1),1);
J=zeros((iz2-iz1+1)*(jz2-jz1+1),1);

for i=iz1:iz2
    for j=jz1:jz2
        Xi(1,k)=xi(i,j);
        Yi(1,k)=yi(i,j);
        I(k,1)=i;
        J(k,1)=j;
        k=k+1;
    end
end

Xi=(repmat(Xi,nz,1));
Yi=(repmat(Yi,nz,1));

%normalization
xi0=(Xi-(xp0))/fx;
yi0=(Yi-(yp0))/fy;

%undistort
x_xi0=xi0;
x_yi0=yi0;
xd_xi0=x_xi0;
xd_yi0=x_yi0;


r_2 = repmat((sum(x_xi0.^2+x_yi0.^2)),nz,1);
k_radial = 1 + k1 * r_2 + k2 * r_2.^2 + k3 * r_2.^3;
delta_x_x = 2*p1*x_xi0.*x_yi0 + p2*(r_2 + 2*x_xi0.^2);
delta_x_y=p1 * (r_2 + 2*x_yi0.^2)+2*p2*x_xi0.*x_yi0;
xx_x = (xd_xi0 - delta_x_x)./(k_radial);
xx_y = (xd_yi0 - delta_x_y)./(k_radial);

%denormalization
xc=xx_x*fx;
yc=xx_y*fy;


% computation of object coordinates
[sf1,sf2]=size(xc);
fv=ones(sf1,sf2)*f;
fv2=fv.^2;
Zc=(DIST.*f)./(sqrt(xc.*xc+yc.*yc+fv2));
Xc=(Zc.*xc)./fv;
Yc=(Zc.*yc)./fv;


opr_z=repmat(DISTl,1,(iz2-iz1+1)*(jz2-jz1+1))-Zc;
Xc_opr=((DIST.*cos(atan(yc./sqrt(f^2+xc.^2))).*cos(atan(xc./f))+opr_z).*xc)./f;
Yc_opr=((DIST.*cos(atan(yc./sqrt(f^2+xc.^2))).*cos(atan(xc./f))+opr_z).*yc)./f;
opr_x=Xc_opr-Xc;
opr_y=Yc_opr-Yc;

opr_DIST=zeros(nz,(iz2-iz1+1)*(jz2-jz1+1));

for i=1:nz
    for j=1:((iz2-iz1+1)*(jz2-jz1+1))
        if opr_z>0
            opr_DIST(i,j)=sqrt(opr_z(i,j).*opr_z(i,j)+opr_x(i,j).*...
                opr_x(i,j)+opr_y(i,j).*opr_y(i,j));
        else
            opr_DIST(i,j)=(-1)*sqrt(opr_z(i,j).*opr_z(i,j)+opr_x(i,j).*...
                opr_x(i,j)+opr_y(i,j).*opr_y(i,j));
        end
    end
end

distl=repmat(DISTl,1,(iz2-iz1+1)*(jz2-jz1+1));
opr_dist=opr_DIST;


CONF_treshold = str2double(get(handles.edit5,'String'));

c_OK=0;
c_N=0;
for i=1:nz
    for j=1:((iz2-iz1+1)*(jz2-jz1+1))
        if CONF(i,j)> CONF_treshold
            c_OK=c_OK+1;
        else
            opr_dist(i,j)=0;
            %distl(i,j)=1.5;
            opr_DIST(i,j)=NaN;
            c_N=c_N+1;
        end
    end
end


switch model
    case 1
        [results] = regresion_analyses_Model1(DIST, opr_DIST, iz1, iz2,...
            jz1, jz2, nz, I, J,d1,c_OK,c_N,CONF_treshold);
    case 2
        [results] = regresion_analyses_Model2(DIST, opr_DIST, iz1, iz2,...
            jz1, jz2, nz, I, J,d1,c_OK,c_N,CONF_treshold);
    otherwise
        disp('regresion model was not choosed')
end

d1.setVisible(false);

%save
end
