
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   cost
%   by Petra Kocmanova
%   last modified: 27.6.2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [cost] = cost(init_data,cam_par0,k)
%Cost function

global use_im
global images

cam_par=cam_par0;

%Camera matrix K
cam_par.K=[init_data(1) 0 init_data(3);
    0 init_data(2) init_data(4);
    0 0 1];

%Distortion coefficient
coef_number = min([4 length(cam_par0.kc)]);
cam_par.kc=[init_data(5:(5+coef_number-1)) zeros(1,5-coef_number)];

%Extrinsic parameters
l=5+coef_number;
cam_par.R=cell(size(cam_par0.R));
j=size(cam_par0.R,2);

for i=1:j
    R=rotationmat(init_data(l:l+2));
    cam_par.R{i}=R;
    cam_par.t{i}=init_data(l+3:l+5)';
    l=l+6;
end


cost=[];
[images_number]=size(images,1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%project images
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:images_number
    if use_im(k,i)
        Xc = bsxfun(@plus,cam_par.R{i}*images(i,k).grid_x,cam_par.t{i});
        %Normalization
        Xn = bsxfun(@rdivide,Xc(1:2,:),Xc(3,:));
        
        if(any(cam_par.kc))
            %Distort
            Xd = distort(Xn,cam_par.kc);
        else
            Xd = Xn;
        end
        
        %Project to image plane
        p = [cam_par.K(1,1)*Xd(1,:) + cam_par.K(1,3);
            cam_par.K(2,2)*Xd(2,:) + cam_par.K(2,3)];
        
        rep_error=p-images(i,k).grid_p(1:2,:);
        cost = [cost; reshape(rep_error,[numel(rep_error),1])];
    end
end

end

