
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   regresion_analyses_Model1
%   by Petra Kocmanova
%   last modified: 27.6.2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [results] = regresion_analyses_Model1( DIST, opr_DIST,...
    iz1, iz2, jz1, jz2, nz,  I, J, d1,c_OK,c_N, CONF_treshold)
%Determine regression coefficients for distance correction
%   Regression Model 1 (opr_DIST=b*DISTl)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Variable definition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p_g2_OK=0;
p_g2_N=0;
p_r2_OK=0;
p_r2_N=0;

beta_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
se_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
p_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
dev_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
sfit_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
stat_resid_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),4);
normr_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);

beta_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
se_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
p_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
s_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),4);
stat_resid_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),4);
normr_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);

opr_DIST_est_g2=NaN(nz,(iz2-iz1+1)*(jz2-jz1+1));
opr_DIST_est_r2=NaN(nz,(iz2-iz1+1)*(jz2-jz1+1));

Sr_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
St_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
Sy_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
r2_g2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
squares_Ok_g2=0;
squares_S_g2=0;
squares_N_g2=0;
tvv_g2=0;
tv_g2=0;
t_g2=0;
tm_g2=0;


Sr_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
St_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
Sy_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
r2_r2=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
squares_Ok_r2=0;
squares_S_r2=0;
squares_N_r2=0;
tvv_r2=0;
tv_r2=0;
t_r2=0;
tm_r2=0;

reg1=1;
reg2=1;
reg3=1;
reg4=1;
rad_dist=sqrt((I-72.5).^2+(J-86.5).^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Model 1 (opr_DIST=b*DISTl) - regresion analyses for TOF camera pixels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:((iz2-iz1+1)*(jz2-jz1+1))
     if sum(isnan(opr_DIST(1:nz,i)))<(nz-7)
        
        [b2_g,dev2_g,stats2_g] = glmfit(DIST(1:nz,i), opr_DIST(1:nz,i),'normal','constant','off');
        opr_DIST_est_g2(1:nz,i)=glmval(b2_g,DIST(1:nz,i),'identity',stats2_g,'constant','off');
        
        [b2_r, stats2_r]= robustfit(DIST(1:nz,i), opr_DIST(1:nz,i),'bisquare',4.685,'off');
        opr_DIST_est_r2(1:nz,i)=glmval(b2_r,DIST(1:nz,i),'identity','constant','off');
        
        beta_g2(i,1)=b2_g;
        se_g2(i,1)=stats2_g.se;
        p_g2(i,1)=stats2_g.p;
        dev_g2(i,1)=dev2_g;
        sfit_g2(i,1)=stats2_g.sfit;
        stat_resid_g2(i,1)=min(abs(stats2_g.resid));
        stat_resid_g2(i,2)=max(abs(stats2_g.resid));
        stat_resid_g2(i,3)=nanmean(abs(stats2_g.resid));
        stat_resid_g2(i,4)=nanmedian(abs(stats2_g.resid));
        normr_g2(i,1)=sqrt(nansum(stats2_g.resid.*stats2_g.resid));
        Sr_g2(i,1)=nansum((opr_DIST(1:nz,i)-opr_DIST_est_g2(1:nz,i)).^2);
        Sy_g2(i,1)=nansum((opr_DIST(1:nz,i)).^2);
        St_g2(i,1)= Sy_g2(i,1)- Sr_g2(i,1);
        r2_g2(i,1)= 1-Sr_g2(i,1)/Sy_g2(i,1);
        
        %Testing if theoretical sum of squares is greater than residual sum
        %of squares (function glmfit)
        if St_g2(i,1)>(2*Sr_g2(i,1))
            squares_Ok_g2=squares_Ok_g2+1;
        elseif St_g2(i,1)>Sr_g2(i,1)
            squares_S_g2=squares_S_g2+1;
        else
            squares_N_g2=squares_N_g2+1;
        end
        
        %Testing of the determination coeficients (function glmfit)
        if r2_g2(i,1)>0.8
            tvv_g2=tvv_g2+1;
        elseif r2_g2(i,1)>0.5&&r2_g2(i,1)<0.8
            tv_g2=tv_g2+1;
        elseif r2_g2(i,1)>0.25&&r2_g2(i,1)<0.5
            t_g2=t_g2+1;
        else
            tm_g2=tm_g2+1;
        end
        
        beta_r2(i,1)=b2_r;
        se_r2(i,1)=stats2_r.se;
        p_r2(i,1)=stats2_r.p;
        s_r2(i,1)=stats2_r.ols_s;
        s_r2(i,2)=stats2_r.robust_s;
        s_r2(i,3)=stats2_r.mad_s;
        s_r2(i,4)=stats2_r.s;
        stat_resid_r2(i,1)=min(abs(stats2_r.resid));
        stat_resid_r2(i,2)=max(abs(stats2_r.resid));
        stat_resid_r2(i,3)=nanmean(abs(stats2_r.resid));
        stat_resid_r2(i,4)=nanmedian(abs(stats2_r.resid));
        normr_r2(i,1)=sqrt(nansum(stats2_r.resid.*stats2_r.resid));
        Sr_r2(i,1)=nansum((opr_DIST(1:nz,i)-opr_DIST_est_r2(1:nz,i)).^2);
        Sy_r2(i,1)=nansum((opr_DIST(1:nz,i)).^2);
        St_r2(i,1)= Sy_r2(i,1)- Sr_r2(i,1);
        r2_r2(i,1)= 1-Sr_r2(i,1)/Sy_r2(i,1);
        
        %Testing if theoretical sum of squares is greater than residual sum
        %of squares (function robustfit)
        if St_r2(i,1)>(2*Sr_r2(i,1))
            squares_Ok_r2=squares_Ok_r2+1;
        elseif St_r2(i,1)>Sr_r2(i,1)
            squares_S_r2=squares_S_r2+1;
        else
            squares_N_r2=squares_N_r2+1;
        end
        
        %Testing of the determination coeficients (function robustfit)
        if r2_r2(i,1)>0.8
            tvv_r2=tvv_r2+1;
        elseif r2_r2(i,1)>0.5&&r2_r2(i,1)<0.8
            tv_r2=tv_r2+1;
        elseif r2_r2(i,1)>0.25&&r2_r2(i,1)<0.5
            t_r2=t_r2+1;
        else
            tm_r2=tm_r2+1;
        end
        
        %Testing of p-value (for good regression model p should be smaller
        %than 0.05)
        
        %(function glmfit)
        if stats2_g.p<0.05
            p_g2_OK=p_g2_OK+1;
        else
            p_g2_N=p_g2_N+1;
        end
        
        
        %(function robustfit
        if stats2_r.p<0.05
            p_r2_OK=p_r2_OK+1;
        else
            p_r2_N=p_r2_N+1;
        end
        

%Testing accordint to SwissRanger regions            
        if J(i,1)>66 && J(i,1)<79 && I(i,1)>80 && I(i,1)<92
            opr_DIST_reg1(:,reg1)=opr_DIST(:,i);
            opr_DIST_est_g2_reg1(:,reg1)=opr_DIST_est_g2(:,i);
            opr_DIST_est_r2_reg1(:,reg1)=opr_DIST_est_r2(:,i);
            
            St_g2_reg1(1,reg1)=St_g2(i,1);
            Sr_g2_reg1(1,reg1)=Sr_g2(i,1);
            St_r2_reg1(1,reg1)=St_r2(i,1);
            Sr_r2_reg1(1,reg1)=Sr_r2(i,1);
            
            r2_g2_reg1(1,reg1)=r2_g2(i,1);
            r2_r2_reg1(1,reg1)=r2_r2(i,1);
            
            stats2_g_p_reg1(1,reg1)=stats2_g.p(1);
            stats2_r_p_reg1(1,reg1)=stats2_r.p(1);
 
            reg1=reg1+1;
            
        elseif rad_dist(i,1)<45
            opr_DIST_reg2(:,reg2)=opr_DIST(:,i);
            opr_DIST_est_g2_reg2(:,reg2)=opr_DIST_est_g2(:,i);
            opr_DIST_est_r2_reg2(:,reg2)=opr_DIST_est_r2(:,i);
            
            St_g2_reg2(1,reg2)=St_g2(i,1);
            Sr_g2_reg2(1,reg2)=Sr_g2(i,1);
            St_r2_reg2(1,reg2)=St_r2(i,1);
            Sr_r2_reg2(1,reg2)=Sr_r2(i,1);
            
            r2_g2_reg2(1,reg2)=r2_g2(i,1);
            r2_r2_reg2(1,reg2)=r2_r2(i,1);
            
            stats2_g_p_reg2(1,reg2)=stats2_g.p(1);
            stats2_r_p_reg2(1,reg2)=stats2_r.p(1);
            
            reg2=reg2+1;
            
        elseif rad_dist(i,1)<69
            opr_DIST_reg3(:,reg3)=opr_DIST(:,i);
            opr_DIST_est_g2_reg3(:,reg3)=opr_DIST_est_g2(:,i);
            opr_DIST_est_r2_reg3(:,reg3)=opr_DIST_est_r2(:,i);
            
            St_g2_reg3(1,reg3)=St_g2(i,1);
            Sr_g2_reg3(1,reg3)=Sr_g2(i,1);
            St_r2_reg3(1,reg3)=St_r2(i,1);
            Sr_r2_reg3(1,reg3)=Sr_r2(i,1);
            
            r2_g2_reg3(1,reg3)=r2_g2(i,1);
            r2_r2_reg3(1,reg3)=r2_r2(i,1);
            
            stats2_g_p_reg3(1,reg3)=stats2_g.p(1);
            stats2_r_p_reg3(1,reg3)=stats2_r.p(1);
            
            reg3=reg3+1;
            
        else
            opr_DIST_reg4(:,reg4)=opr_DIST(:,i);
            opr_DIST_est_g2_reg4(:,reg4)=opr_DIST_est_g2(:,i);
            opr_DIST_est_r2_reg4(:,reg4)=opr_DIST_est_r2(:,i);
            
            St_g2_reg4(1,reg4)=St_g2(i,1);
            Sr_g2_reg4(1,reg4)=Sr_g2(i,1);
            St_r2_reg4(1,reg4)=St_r2(i,1);
            Sr_r2_reg4(1,reg4)=Sr_r2(i,1);
            
            r2_g2_reg4(1,reg4)=r2_g2(i,1);
            r2_r2_reg4(1,reg4)=r2_r2(i,1);
            
            stats2_g_p_reg4(1,reg4)=stats2_g.p(1);
            stats2_r_p_reg4(1,reg4)=stats2_r.p(1);
            
            reg4=reg4+1;
        end
        
        
        
        proc=0.5+0.45*i/((iz2-iz1+1)*(jz2-jz1+1));
        d1.setValue(proc);
            d1.setProgressStatusLabel(['Processing...regression model calculation('...
        int2str(i) '/' int2str((iz2-iz1+1)*(jz2-jz1+1)) ')']); 
     end
end



d1.setProgressStatusLabel('Processing...saving results');        
[mp,np]=size(opr_DIST);
SD_before=sqrt(nansum(nansum((opr_DIST).*(opr_DIST)))/(mp*np-sum(sum(isnan(opr_DIST)))));
SD_after_g2=sqrt(nansum(nansum((opr_DIST-opr_DIST_est_g2).*(opr_DIST-opr_DIST_est_g2)))/(mp*np-sum(sum(isnan(opr_DIST)))));
SD_after_r2=sqrt(nansum(nansum((opr_DIST-opr_DIST_est_r2).*(opr_DIST-opr_DIST_est_r2)))/(mp*np-sum(sum(isnan(opr_DIST)))));

if exist('opr_DIST_reg1','var')
[mp_reg1,np_reg1]=size(opr_DIST_reg1);
SD_before_reg1=sqrt(nansum(nansum((opr_DIST_reg1).*(opr_DIST_reg1)))/(mp_reg1*np_reg1-sum(sum(isnan(opr_DIST_reg1)))));
SD_after_g2_reg1=sqrt(nansum(nansum((opr_DIST_reg1-opr_DIST_est_g2_reg1).*(opr_DIST_reg1-opr_DIST_est_g2_reg1)))/(mp_reg1*np_reg1-sum(sum(isnan(opr_DIST_reg1)))));
SD_after_r2_reg1=sqrt(nansum(nansum((opr_DIST_reg1-opr_DIST_est_r2_reg1).*(opr_DIST_reg1-opr_DIST_est_r2_reg1)))/(mp_reg1*np_reg1-sum(sum(isnan(opr_DIST_reg1)))));

Sd_reg1=St_g2_reg1-Sr_g2_reg1;
squares_Ok_g2_reg1=size((Sd_reg1(Sd_reg1>0)),2);
squares_N_g2_reg1=size((Sd_reg1(Sd_reg1<=0)),2);

Sd_reg1=St_r2_reg1-Sr_r2_reg1;
squares_Ok_r2_reg1=size((Sd_reg1(Sd_reg1>0)),2);
squares_N_r2_reg1=size((Sd_reg1(Sd_reg1<=0)),2);

tvv_g2_reg1=size((r2_g2_reg1(r2_g2_reg1>0.8)),2);
tv_g2_reg1=size((r2_g2_reg1(r2_g2_reg1<=0.8&r2_g2_reg1>0.5)),2);
t_g2_reg1=size((r2_g2_reg1(r2_g2_reg1<=0.5&r2_g2_reg1>0.25)),2);
tm_g2_reg1=size((r2_g2_reg1(r2_g2_reg1<=0.25)),2);

tvv_r2_reg1=size((r2_r2_reg1(r2_r2_reg1>0.8)),2);
tv_r2_reg1=size((r2_r2_reg1(r2_r2_reg1<=0.8&r2_r2_reg1>0.5)),2);
t_r2_reg1=size((r2_r2_reg1(r2_r2_reg1<=0.5&r2_r2_reg1>0.25)),2);
tm_r2_reg1=size((r2_r2_reg1(r2_r2_reg1<=0.25)),2);

p_g2_OK_reg1=size((stats2_g_p_reg1(stats2_g_p_reg1<0.05)),2);
p_g2_N_reg1=size((stats2_g_p_reg1(stats2_g_p_reg1>=0.05)),2);

p_r2_OK_reg1=size((stats2_r_p_reg1(stats2_r_p_reg1<0.05)),2);
p_r2_N_reg1=size((stats2_r_p_reg1(stats2_r_p_reg1>=0.05)),2);

results_reg1=[p_g2_OK_reg1 p_r2_OK_reg1;
    p_g2_N_reg1 p_r2_N_reg1;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g2_reg1 squares_Ok_r2_reg1;
    squares_N_g2_reg1 squares_N_r2_reg1;
    nan nan;
    tvv_g2_reg1 tvv_r2_reg1;
    tv_g2_reg1 tv_r2_reg1;
    t_g2_reg1 t_r2_reg1
    tm_g2_reg1 tm_r2_reg1;
    nan nan;
    round(SD_before_reg1*1000)/1000 round(SD_before_reg1*1000)/1000;
    round(SD_after_g2_reg1*1000)/1000 round(SD_after_r2_reg1*1000)/1000];

end

if exist('opr_DIST_reg2','var')
[mp_reg2,np_reg2]=size(opr_DIST_reg2);
SD_before_reg2=sqrt(nansum(nansum((opr_DIST_reg2).*(opr_DIST_reg2)))/(mp_reg2*np_reg2-sum(sum(isnan(opr_DIST_reg2)))));
SD_after_g2_reg2=sqrt(nansum(nansum((opr_DIST_reg2-opr_DIST_est_g2_reg2).*(opr_DIST_reg2-opr_DIST_est_g2_reg2)))/(mp_reg2*np_reg2-sum(sum(isnan(opr_DIST_reg2)))));
SD_after_r2_reg2=sqrt(nansum(nansum((opr_DIST_reg2-opr_DIST_est_r2_reg2).*(opr_DIST_reg2-opr_DIST_est_r2_reg2)))/(mp_reg2*np_reg2-sum(sum(isnan(opr_DIST_reg2)))));

Sd_reg2=St_g2_reg2-Sr_g2_reg2;
squares_Ok_g2_reg2=size((Sd_reg2(Sd_reg2>0)),2);
squares_N_g2_reg2=size((Sd_reg2(Sd_reg2<=0)),2);

Sd_reg2=St_r2_reg2-Sr_r2_reg2;
squares_Ok_r2_reg2=size((Sd_reg2(Sd_reg2>0)),2);
squares_N_r2_reg2=size((Sd_reg2(Sd_reg2<=0)),2);

tvv_g2_reg2=size((r2_g2_reg2(r2_g2_reg2>0.8)),2);
tv_g2_reg2=size((r2_g2_reg2(r2_g2_reg2<=0.8&r2_g2_reg2>0.5)),2);
t_g2_reg2=size((r2_g2_reg2(r2_g2_reg2<=0.5&r2_g2_reg2>0.25)),2);
tm_g2_reg2=size((r2_g2_reg2(r2_g2_reg2<=0.25)),2);

tvv_r2_reg2=size((r2_r2_reg2(r2_r2_reg2>0.8)),2);
tv_r2_reg2=size((r2_r2_reg2(r2_r2_reg2<=0.8&r2_r2_reg2>0.5)),2);
t_r2_reg2=size((r2_r2_reg2(r2_r2_reg2<=0.5&r2_r2_reg2>0.25)),2);
tm_r2_reg2=size((r2_r2_reg2(r2_r2_reg2<=0.25)),2);

p_g2_OK_reg2=size((stats2_g_p_reg2(stats2_g_p_reg2<0.05)),2);
p_g2_N_reg2=size((stats2_g_p_reg2(stats2_g_p_reg2>=0.05)),2);

p_r2_OK_reg2=size((stats2_r_p_reg2(stats2_r_p_reg2<0.05)),2);
p_r2_N_reg2=size((stats2_r_p_reg2(stats2_r_p_reg2>=0.05)),2);

results_reg2=[p_g2_OK_reg2 p_r2_OK_reg2;
    p_g2_N_reg2 p_r2_N_reg2;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g2_reg2 squares_Ok_r2_reg2;
    squares_N_g2_reg2 squares_N_r2_reg2;
    nan nan;
    tvv_g2_reg2 tvv_r2_reg2;
    tv_g2_reg2 tv_r2_reg2;
    t_g2_reg2 t_r2_reg2
    tm_g2_reg2 tm_r2_reg2;
    nan nan;
    round(SD_before_reg2*1000)/1000 round(SD_before_reg2*1000)/1000;
    round(SD_after_g2_reg2*1000)/1000 round(SD_after_r2_reg2*1000)/1000];

end

if exist('opr_DIST_reg3','var')
[mp_reg3,np_reg3]=size(opr_DIST_reg3);
SD_before_reg3=sqrt(nansum(nansum((opr_DIST_reg3).*(opr_DIST_reg3)))/(mp_reg3*np_reg3-sum(sum(isnan(opr_DIST_reg3)))));
SD_after_g2_reg3=sqrt(nansum(nansum((opr_DIST_reg3-opr_DIST_est_g2_reg3).*(opr_DIST_reg3-opr_DIST_est_g2_reg3)))/(mp_reg3*np_reg3-sum(sum(isnan(opr_DIST_reg3)))));
SD_after_r2_reg3=sqrt(nansum(nansum((opr_DIST_reg3-opr_DIST_est_r2_reg3).*(opr_DIST_reg3-opr_DIST_est_r2_reg3)))/(mp_reg3*np_reg3-sum(sum(isnan(opr_DIST_reg3)))));

Sd_reg3=St_g2_reg3-Sr_g2_reg3;
squares_Ok_g2_reg3=size((Sd_reg3(Sd_reg3>0)),2);
squares_N_g2_reg3=size((Sd_reg3(Sd_reg3<=0)),2);

Sd_reg3=St_r2_reg3-Sr_r2_reg3;
squares_Ok_r2_reg3=size((Sd_reg3(Sd_reg3>0)),2);
squares_N_r2_reg3=size((Sd_reg3(Sd_reg3<=0)),2);

tvv_g2_reg3=size((r2_g2_reg3(r2_g2_reg3>0.8)),2);
tv_g2_reg3=size((r2_g2_reg3(r2_g2_reg3<=0.8&r2_g2_reg3>0.5)),2);
t_g2_reg3=size((r2_g2_reg3(r2_g2_reg3<=0.5&r2_g2_reg3>0.25)),2);
tm_g2_reg3=size((r2_g2_reg3(r2_g2_reg3<=0.25)),2);

tvv_r2_reg3=size((r2_r2_reg3(r2_r2_reg3>0.8)),2);
tv_r2_reg3=size((r2_r2_reg3(r2_r2_reg3<=0.8&r2_r2_reg3>0.5)),2);
t_r2_reg3=size((r2_r2_reg3(r2_r2_reg3<=0.5&r2_r2_reg3>0.25)),2);
tm_r2_reg3=size((r2_r2_reg3(r2_r2_reg3<=0.25)),2);

p_g2_OK_reg3=size((stats2_g_p_reg3(stats2_g_p_reg3<0.05)),2);
p_g2_N_reg3=size((stats2_g_p_reg3(stats2_g_p_reg3>=0.05)),2);

p_r2_OK_reg3=size((stats2_r_p_reg3(stats2_r_p_reg3<0.05)),2);
p_r2_N_reg3=size((stats2_r_p_reg3(stats2_r_p_reg3>=0.05)),2);

results_reg3=[p_g2_OK_reg3 p_r2_OK_reg3;
    p_g2_N_reg3 p_r2_N_reg3;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g2_reg3 squares_Ok_r2_reg3;
    squares_N_g2_reg3 squares_N_r2_reg3;
    nan nan;
    tvv_g2_reg3 tvv_r2_reg3;
    tv_g2_reg3 tv_r2_reg3;
    t_g2_reg3 t_r2_reg3
    tm_g2_reg3 tm_r2_reg3;
    nan nan;
    round(SD_before_reg3*1000)/1000 round(SD_before_reg3*1000)/1000;
    round(SD_after_g2_reg3*1000)/1000 round(SD_after_r2_reg3*1000)/1000];
end

if exist('opr_DIST_reg4','var')
[mp_reg4,np_reg4]=size(opr_DIST_reg4);
SD_before_reg4=sqrt(nansum(nansum((opr_DIST_reg4).*(opr_DIST_reg4)))/(mp_reg4*np_reg4-sum(sum(isnan(opr_DIST_reg4)))));
SD_after_g2_reg4=sqrt(nansum(nansum((opr_DIST_reg4-opr_DIST_est_g2_reg4).*(opr_DIST_reg4-opr_DIST_est_g2_reg4)))/(mp_reg4*np_reg4-sum(sum(isnan(opr_DIST_reg4)))));
SD_after_r2_reg4=sqrt(nansum(nansum((opr_DIST_reg4-opr_DIST_est_r2_reg4).*(opr_DIST_reg4-opr_DIST_est_r2_reg4)))/(mp_reg4*np_reg4-sum(sum(isnan(opr_DIST_reg4)))));

Sd_reg4=St_g2_reg4-Sr_g2_reg4;
squares_Ok_g2_reg4=size((Sd_reg4(Sd_reg4>0)),2);
squares_N_g2_reg4=size((Sd_reg4(Sd_reg4<=0)),2);

Sd_reg4=St_r2_reg4-Sr_r2_reg4;
squares_Ok_r2_reg4=size((Sd_reg4(Sd_reg4>0)),2);
squares_N_r2_reg4=size((Sd_reg4(Sd_reg4<=0)),2);

tvv_g2_reg4=size((r2_g2_reg4(r2_g2_reg4>0.8)),2);
tv_g2_reg4=size((r2_g2_reg4(r2_g2_reg4<=0.8&r2_g2_reg4>0.5)),2);
t_g2_reg4=size((r2_g2_reg4(r2_g2_reg4<=0.5&r2_g2_reg4>0.25)),2);
tm_g2_reg4=size((r2_g2_reg4(r2_g2_reg4<=0.25)),2);

tvv_r2_reg4=size((r2_r2_reg4(r2_r2_reg4>0.8)),2);
tv_r2_reg4=size((r2_r2_reg4(r2_r2_reg4<=0.8&r2_r2_reg4>0.5)),2);
t_r2_reg4=size((r2_r2_reg4(r2_r2_reg4<=0.5&r2_r2_reg4>0.25)),2);
tm_r2_reg4=size((r2_r2_reg4(r2_r2_reg4<=0.25)),2);

p_g2_OK_reg4=size((stats2_g_p_reg4(stats2_g_p_reg4<0.05)),2);
p_g2_N_reg4=size((stats2_g_p_reg4(stats2_g_p_reg4>=0.05)),2);

p_r2_OK_reg4=size((stats2_r_p_reg4(stats2_r_p_reg4<0.05)),2);
p_r2_N_reg4=size((stats2_r_p_reg4(stats2_r_p_reg4>=0.05)),2);

results_reg4=[p_g2_OK_reg4 p_r2_OK_reg4;
    p_g2_N_reg4 p_r2_N_reg4;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g2_reg4 squares_Ok_r2_reg4;
    squares_N_g2_reg4 squares_N_r2_reg4;
    nan nan;
    tvv_g2_reg4 tvv_r2_reg4;
    tv_g2_reg4 tv_r2_reg4;
    t_g2_reg4 t_r2_reg4
    tm_g2_reg4 tm_r2_reg4;
    nan nan;
    round(SD_before_reg4*1000)/1000 round(SD_before_reg4*1000)/1000;
    round(SD_after_g2_reg4*1000)/1000 round(SD_after_r2_reg4*1000)/1000];

end


results=[SD_before;SD_after_r2;squares_Ok_r2;squares_S_r2;...
    squares_N_r2;(iz2-iz1+1)*(jz2-jz1+1)];

blok4=cell((iz2-iz1+1)*(jz2-jz1+1)+2,19);

blok4(1,1) = {'Model 1 (opr_DIST=b*DISTl)'};
blok4(1,3) = {'glmfit'};
blok4(2,2:16) = { 'b','se_b','p_b',...
    'min resid. [m]','max resid.[m]','mean resid.[m]','median resid.[m]',...
    '','i','j','','Sr [m2]','St [m2]','Sy [m2]','r2'};

blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),1)=num2cell((1:1:(iz2-iz1+1)*(jz2-jz1+1))');
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),2)=num2cell(round(beta_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),3)=num2cell(round(se_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),4)=num2cell(round(p_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),5:8)=num2cell(round(stat_resid_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),10)=num2cell(I(1:((iz2-iz1+1)*(jz2-jz1+1)),1));
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),11)=num2cell(J(1:((iz2-iz1+1)*(jz2-jz1+1)),1));

blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),13)=num2cell(round(Sr_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),14)=num2cell(round(St_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),15)=num2cell(round(Sy_g2*1000)/1000);
blok4(3:((iz2-iz1+1)*(jz2-jz1+1)+2),16)=num2cell(round(r2_g2*1000)/1000);



blok5=cell((iz2-iz1+1)*(jz2-jz1+1)+2,21);

blok5(1,1) = {'Model 1 (opr_DIST=b*DISTl)'};
blok5(1,3) = {'robusfit'};
blok5(2,2:16) = {'b','se_b','p_b',...
    'min resid. [m]','max resid.[m]','mean resid.[m]','median resid.[m]',...
    '','i','j','','Sr [m2]','St [m2]','Sy [m2]','r2'};

blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),1)=num2cell((1:1:(iz2-iz1+1)*(jz2-jz1+1))');
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),2)=num2cell(round(beta_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),3)=num2cell(round(se_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),4)=num2cell(round(p_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),5:8)=num2cell(round(stat_resid_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),10)=num2cell(I(1:((iz2-iz1+1)*(jz2-jz1+1)),1));
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),11)=num2cell(J(1:((iz2-iz1+1)*(jz2-jz1+1)),1));

blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),13)=num2cell(round(Sr_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),14)=num2cell(round(St_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),15)=num2cell(round(Sy_r2*1000)/1000);
blok5(3:((iz2-iz1+1)*(jz2-jz1+1)+2),16)=num2cell(round(r2_r2*1000)/1000);

blok8=cell(32,11);

blok8(1,1)={'Results summary'};
blok8(2,2:11)={'Total','Total','Region 1','Region 1','Region 2','Region 2',...
    'Region 3','Region 3','Region 4','Region 4'};
blok8(3,2:11)={'glmfit','robustfit','glmfit','robustfit','glmfit',...
    'robustfit','glmfit','robustfit','glmfit','robustfit'};
blok8(4,1)={'count of pixel with p1 < 0.05'};
blok8(5,1)={'count of pixel with p1 > 0.05'};

blok8(7:9,1)={'max resid. [m]','mean resid [m]','median resid. [m]'};

blok8(11:24,1)={'count of pixel with St > Sr','count of pixel with St < Sr',...
    '','count of pixel with r2 > 0,80','count of pixel with 0,50 < r2 < 0,80'...
    ,'count of pixel with 0,25 < r2 < 0,50','count of pixel with r2 < 0,25',...
    '','distance SD before calibration [m]',...
    'distance SD after calibration [m]','','conf. treshold T [%]',...
    'count of measurement with confidence > T','count of measurement with confidence < T'};

blok8(4,2)=num2cell(p_g2_OK);
blok8(5,2)=num2cell(p_g2_N);
blok8(4,3)=num2cell(p_r2_OK);
blok8(5,3)=num2cell(p_r2_N);

blok8(7,2)=num2cell(round(max(stat_resid_g2(:,2))*1000)/1000);
blok8(8,2)=num2cell(round(nanmean(stat_resid_g2(:,3))*1000)/1000);
blok8(9,2)=num2cell(round(nanmedian(stat_resid_g2(:,4))*1000)/1000);

blok8(7,3)=num2cell(round(max(stat_resid_r2(:,2))*1000)/1000);
blok8(8,3)=num2cell(round(nanmean(stat_resid_r2(:,3))*1000)/1000);
blok8(9,3)=num2cell(round(nanmedian(stat_resid_r2(:,4))*1000)/1000);

blok8(11,2:3)=[num2cell(squares_Ok_g2+squares_S_g2),num2cell(squares_Ok_r2+squares_S_r2)];
blok8(12,2:3)=[num2cell(squares_N_g2),num2cell(squares_N_r2)];

blok8(14,2:3)=[num2cell(tvv_g2),num2cell(tvv_r2)];
blok8(15,2:3)=[num2cell(tv_g2),num2cell(tv_r2)];
blok8(16,2:3)=[num2cell(t_g2),num2cell(t_r2)];
blok8(17,2:3)=[num2cell(tm_g2),num2cell(tm_r2)];


blok8(19,2:3)=[num2cell(round(SD_before*1000)/1000),num2cell(round(SD_before*1000)/1000)];
blok8(20,2:3)=[num2cell(round(SD_after_g2*1000)/1000),num2cell(round(SD_after_r2*1000)/1000)];

if exist('results_reg1','var')
    blok8(4:20,4:5)=num2cell(results_reg1);
end

if exist('results_reg2','var')
    blok8(4:20,6:7)=num2cell(results_reg2);
end

if exist('results_reg3','var')
    blok8(4:20,8:9)=num2cell(results_reg3);
end

if exist('results_reg4','var')
    blok8(4:20,10:11)=num2cell(results_reg4);
end

blok8(22,2)=num2cell(CONF_treshold);
blok8(23,2:3)=[num2cell(c_OK),num2cell(c_OK)];
blok8(24,2:3)=[num2cell(c_N),num2cell(c_N)];

excelFileName='Regrese_Model1.xls';

xlswrite(excelFileName, blok4,'GLMFIT');
xlswrite(excelFileName, blok5,'ROBUSTFIT');
xlswrite(excelFileName, blok8,'OVERVIEW');


delete_default_sheet(excelFileName)

end

