
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   regresion_analyses_Model2
%   by Petra Kocmanova
%   last modified: 27.6.2015
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
 function [results]=regresion_analyses_Model2(DIST, opr_DIST,...
    iz1, iz2, jz1, jz2, nz,  I, J,d1,c_OK,c_N, CONF_treshold)
%Determine regression coefficients for distance correction
%   Regression Model 2 (opr_DIST=b1+b2*DISTl)   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Variable definition
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p1_g1_OK=0;
p1_g1_N=0;
p1_r1_OK=0;
p1_r1_N=0;
p2_g1_OK=0;
p2_g1_N=0;
p2_r1_OK=0;
p2_r1_N=0;
corr_g1_OK=0;
corr_g1_N=0;
corr_r1_OK=0;
corr_r1_N=0;

beta_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),2);
se_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),2);
p_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),2);
corr_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
dev_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
sfit_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
stat_resid_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),4);
normr_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);

beta_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),2);
se_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),2);
p_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),2);
corr_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
s_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),4);
stat_resid_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),4);
normr_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);

opr_DIST_est_g1=NaN(nz,(iz2-iz1+1)*(jz2-jz1+1));
opr_DIST_est_r1=NaN(nz,(iz2-iz1+1)*(jz2-jz1+1));

Sr_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
St_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
Sy_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
r2_g1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
squares_Ok_g1=0;
squares_S_g1=0;
squares_N_g1=0;
tvv_g1=0;
tv_g1=0;
t_g1=0;
tm_g1=0;

Sr_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
St_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
Sy_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
r2_r1=NaN((iz2-iz1+1)*(jz2-jz1+1),1);
squares_Ok_r1=0;
squares_S_r1=0;
squares_N_r1=0;
tvv_r1=0;
tv_r1=0;
t_r1=0;
tm_r1=0;


reg1=1;
reg2=1;
reg3=1;
reg4=1;
rad_dist=sqrt((I-72.5).^2+(J-86.5).^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Model 2 (opr_DIST=b1+b2*DISTl) - regresion analyses for TOF camera pixels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:((iz2-iz1+1)*(jz2-jz1+1))
    if sum(isnan(opr_DIST(1:nz,i)))<(nz-7)

        [b1_g,dev1_g,stats1_g] = glmfit(DIST(1:nz,i), opr_DIST(1:nz,i),...
            'normal','constant','on');
        opr_DIST_est_g1(1:nz,i)=glmval(b1_g,DIST(1:nz,i),...
            'identity',stats1_g,'constant','on');
        
        [b1_r, stats1_r]= robustfit(DIST(1:nz,i), opr_DIST(1:nz,i),...
            'bisquare',4.685,'on');
        opr_DIST_est_r1(1:nz,i)=glmval(b1_r,DIST(1:nz,i),...
            'identity','constant','on');
       
        
        beta_g1(i,1:2)=b1_g';
        se_g1(i,1:2)=stats1_g.se';
        p_g1(i,1:2)=stats1_g.p';
        corr_g1(i,1)=stats1_g.coeffcorr(1,2);
        dev_g1(i,1)=dev1_g;
        sfit_g1(i,1)=stats1_g.sfit;
        stat_resid_g1(i,1)=min(abs(stats1_g.resid));
        stat_resid_g1(i,2)=max(abs(stats1_g.resid));
        stat_resid_g1(i,3)=nanmean(abs(stats1_g.resid));
        stat_resid_g1(i,4)=nanmedian(abs(stats1_g.resid));
        normr_g1(i,1)=sqrt(nansum(stats1_g.resid.*stats1_g.resid));
        Sr_g1(i,1)=nansum((opr_DIST(1:nz,i)-opr_DIST_est_g1(1:nz,i)).^2);
        Sy_g1(i,1)=nansum((opr_DIST(1:nz,i)).^2);
        St_g1(i,1)= Sy_g1(i,1)- Sr_g1(i,1);
        r2_g1(i,1)= 1-Sr_g1(i,1)/Sy_g1(i,1);
        
        %Testing if theoretical sum of squares is greater than residual sum
        %of squares (function glmfit)
        if St_g1(i,1)>(2*Sr_g1(i,1))
            squares_Ok_g1=squares_Ok_g1+1;
        elseif St_g1(i,1)>Sr_g1(i,1)
            squares_S_g1=squares_S_g1+1;
        else
            squares_N_g1=squares_N_g1+1;
        end
        
        %Testing of the determination coeficients (function glmfit)
        if r2_g1(i,1)>0.8
            tvv_g1=tvv_g1+1;
        elseif r2_g1(i,1)>0.5&&r2_g1(i,1)<0.8
            tv_g1=tv_g1+1;
        elseif r2_g1(i,1)>0.25&&r2_g1(i,1)<0.5
            t_g1=t_g1+1;
        else
            tm_g1=tm_g1+1;
        end
        
        
        
        beta_r1(i,1:2)=b1_r';
        se_r1(i,1:2)=stats1_r.se';
        p_r1(i,1:2)=stats1_r.p';
        corr_r1(i,1)=stats1_r.coeffcorr(1,2);
        s_r1(i,1)=stats1_r.ols_s;
        s_r1(i,2)=stats1_r.robust_s;
        s_r1(i,3)=stats1_r.mad_s;
        s_r1(i,4)=stats1_r.s;
        stat_resid_r1(i,1)=min(abs(stats1_r.resid));
        stat_resid_r1(i,2)=max(abs(stats1_r.resid));
        stat_resid_r1(i,3)=nanmean(abs(stats1_r.resid));
        stat_resid_r1(i,4)=nanmedian(abs(stats1_r.resid));
        normr_r1(i,1)=sqrt(nansum(stats1_r.resid.*stats1_r.resid));
        Sr_r1(i,1)=nansum((opr_DIST(1:nz,i)-opr_DIST_est_r1(1:nz,i)).^2);
        Sy_r1(i,1)=nansum((opr_DIST(1:nz,i)).^2);
        St_r1(i,1)= Sy_r1(i,1)- Sr_r1(i,1);
        r2_r1(i,1)= 1-Sr_r1(i,1)/Sy_r1(i,1);
        
        
        %Testing if theoretical sum of squares is greater than residual sum
        %of squares (function robustfit)
        if St_r1(i,1)>(2*Sr_r1(i,1))
            squares_Ok_r1=squares_Ok_r1+1;
        elseif St_r1(i,1)>Sr_r1(i,1)
            squares_S_r1=squares_S_r1+1;
        else
            squares_N_r1=squares_N_r1+1;
        end
        
        %Testing of the determination coeficients (function robustfit)
        if r2_r1(i,1)>0.8
            tvv_r1=tvv_r1+1;
        elseif r2_r1(i,1)>0.5&&r2_r1(i,1)<0.8
            tv_r1=tv_r1+1;
        elseif r2_r1(i,1)>0.25&&r2_r1(i,1)<0.5
            t_r1=t_r1+1;
        else
            tm_r1=tm_r1+1;
        end
        
               
        %Testing of p-value (for good regression model p should be smaller
        %than 0.05)
    
        %(function glmfit)
        if stats1_g.p(1)<0.05
            p1_g1_OK=p1_g1_OK+1;
        else
            p1_g1_N=p1_g1_N+1;
        end
        
        if stats1_g.p(2)<0.05
            p2_g1_OK=p2_g1_OK+1;
        else
            p2_g1_N=p2_g1_N+1;
        end
        
        if abs(stats1_g.coeffcorr(1,2))<0.5
            corr_g1_OK=corr_g1_OK+1;
        else
            corr_g1_N=corr_g1_N+1;
        end
        
        %(function robustfit
        if stats1_r.p(1)<0.05
            p1_r1_OK=p1_r1_OK+1;
        else
            p1_r1_N=p1_r1_N+1;
        end
        
        if stats1_r.p(2)<0.05
            p2_r1_OK=p2_r1_OK+1;
        else
            p2_r1_N=p2_r1_N+1;
        end
        
         if abs(stats1_r.coeffcorr(1,2))<0.5
            corr_r1_OK=corr_r1_OK+1;
        else
            corr_r1_N=corr_r1_N+1;
         end

         
         
         
%Testing accordint to SwissRanger regions        
         if J(i,1)>66 && J(i,1)<79 && I(i,1)>80 && I(i,1)<92
             opr_DIST_reg1(:,reg1)=opr_DIST(:,i);
             opr_DIST_est_g1_reg1(:,reg1)=opr_DIST_est_g1(:,i);
             opr_DIST_est_r1_reg1(:,reg1)=opr_DIST_est_r1(:,i);
             
             St_g1_reg1(1,reg1)=St_g1(i,1);
             Sr_g1_reg1(1,reg1)=Sr_g1(i,1);
             St_r1_reg1(1,reg1)=St_r1(i,1);
             Sr_r1_reg1(1,reg1)=Sr_r1(i,1);
             
             r2_g1_reg1(1,reg1)=r2_g1(i,1);
             r2_r1_reg1(1,reg1)=r2_r1(i,1);
             
             stats1_g_p1_reg1(1,reg1)=stats1_g.p(1);
             stats1_g_p2_reg1(1,reg1)=stats1_g.p(2);
             stats1_r_p1_reg1(1,reg1)=stats1_r.p(1);
             stats1_r_p2_reg1(1,reg1)=stats1_r.p(2);
             
             stats_g_coeffcorr_reg1(1,reg1)=stats1_g.coeffcorr(1,2);
             stats_r_coeffcorr_reg1(1,reg1)=stats1_r.coeffcorr(1,2);
             
             reg1=reg1+1;
             
         elseif rad_dist(i,1)<=44
             opr_DIST_reg2(:,reg2)=opr_DIST(:,i);
             opr_DIST_est_g1_reg2(:,reg2)=opr_DIST_est_g1(:,i);
             opr_DIST_est_r1_reg2(:,reg2)=opr_DIST_est_r1(:,i);
             
             St_g1_reg2(1,reg2)=St_g1(i,1);
             Sr_g1_reg2(1,reg2)=Sr_g1(i,1);
             St_r1_reg2(1,reg2)=St_r1(i,1);
             Sr_r1_reg2(1,reg2)=Sr_r1(i,1);
             
             r2_g1_reg2(1,reg2)=r2_g1(i,1);
             r2_r1_reg2(1,reg2)=r2_r1(i,1);
             
             stats1_g_p1_reg2(1,reg2)=stats1_g.p(1);
             stats1_g_p2_reg2(1,reg2)=stats1_g.p(2);
             stats1_r_p1_reg2(1,reg2)=stats1_r.p(1);
             stats1_r_p2_reg2(1,reg2)=stats1_r.p(2);
             
             stats_g_coeffcorr_reg2(1,reg2)=stats1_g.coeffcorr(1,2);
             stats_r_coeffcorr_reg2(1,reg2)=stats1_r.coeffcorr(1,2);
             
             reg2=reg2+1;
             
             
         elseif rad_dist(i,1)<=69
             opr_DIST_reg3(:,reg3)=opr_DIST(:,i);
             opr_DIST_est_g1_reg3(:,reg3)=opr_DIST_est_g1(:,i);
             opr_DIST_est_r1_reg3(:,reg3)=opr_DIST_est_r1(:,i);
             
             St_g1_reg3(1,reg3)=St_g1(i,1);
             Sr_g1_reg3(1,reg3)=Sr_g1(i,1);
             St_r1_reg3(1,reg3)=St_r1(i,1);
             Sr_r1_reg3(1,reg3)=Sr_r1(i,1);
             
             r2_g1_reg3(1,reg3)=r2_g1(i,1);
             r2_r1_reg3(1,reg3)=r2_r1(i,1);
             
             stats1_g_p1_reg3(1,reg3)=stats1_g.p(1);
             stats1_g_p2_reg3(1,reg3)=stats1_g.p(2);
             stats1_r_p1_reg3(1,reg3)=stats1_r.p(1);
             stats1_r_p2_reg3(1,reg3)=stats1_r.p(2);
             
             stats_g_coeffcorr_reg3(1,reg3)=stats1_g.coeffcorr(1,2);
             stats_r_coeffcorr_reg3(1,reg3)=stats1_r.coeffcorr(1,2);
             
             reg3=reg3+1;
         else
             opr_DIST_reg4(:,reg4)=opr_DIST(:,i);
             opr_DIST_est_g1_reg4(:,reg4)=opr_DIST_est_g1(:,i);
             opr_DIST_est_r1_reg4(:,reg4)=opr_DIST_est_r1(:,i);
             
             St_g1_reg4(1,reg4)=St_g1(i,1);
             Sr_g1_reg4(1,reg4)=Sr_g1(i,1);
             St_r1_reg4(1,reg4)=St_r1(i,1);
             Sr_r1_reg4(1,reg4)=Sr_r1(i,1);
             
             r2_g1_reg4(1,reg4)=r2_g1(i,1);
             r2_r1_reg4(1,reg4)=r2_r1(i,1);
             
             stats1_g_p1_reg4(1,reg4)=stats1_g.p(1);
             stats1_g_p2_reg4(1,reg4)=stats1_g.p(2);
             stats1_r_p1_reg4(1,reg4)=stats1_r.p(1);
             stats1_r_p2_reg4(1,reg4)=stats1_r.p(2);
             
             stats_g_coeffcorr_reg4(1,reg4)=stats1_g.coeffcorr(1,2);
             stats_r_coeffcorr_reg4(1,reg4)=stats1_r.coeffcorr(1,2);
             
             reg4=reg4+1;
         end
         
         
         
         
         
    d1.setValue(0.5+0.45*i/((iz2-iz1+1)*(jz2-jz1+1)));
    d1.setProgressStatusLabel(['Processing...regression model calculation('...
        int2str(i) '/' int2str((iz2-iz1+1)*(jz2-jz1+1)) ')']);
        
    end
end
    
d1.setProgressStatusLabel('Processing...saving results');
[mp,np]=size(opr_DIST);
SD_before=sqrt(nansum(nansum((opr_DIST).*(opr_DIST)))/...
    (mp*np-sum(sum(isnan(opr_DIST)))));
SD_after_g1=sqrt(nansum(nansum((opr_DIST-opr_DIST_est_g1).*...
    (opr_DIST-opr_DIST_est_g1)))/(mp*np-sum(sum(isnan(opr_DIST))))); 
SD_after_r1=sqrt(nansum(nansum((opr_DIST-opr_DIST_est_r1).*...
    (opr_DIST-opr_DIST_est_r1)))/(mp*np-sum(sum(isnan(opr_DIST)))));


%stedn chyby podle jednotlivch region
if exist('opr_DIST_reg1','var')
[mp_reg1,np_reg1]=size(opr_DIST_reg1);
SD_before_reg1=sqrt(nansum(nansum((opr_DIST_reg1).*(opr_DIST_reg1)))/(mp_reg1*np_reg1-sum(sum(isnan(opr_DIST_reg1)))));
SD_after_g1_reg1=sqrt(nansum(nansum((opr_DIST_reg1-opr_DIST_est_g1_reg1).*(opr_DIST_reg1-opr_DIST_est_g1_reg1)))/(mp_reg1*np_reg1-sum(sum(isnan(opr_DIST_reg1)))));
SD_after_r1_reg1=sqrt(nansum(nansum((opr_DIST_reg1-opr_DIST_est_r1_reg1).*(opr_DIST_reg1-opr_DIST_est_r1_reg1)))/(mp_reg1*np_reg1-sum(sum(isnan(opr_DIST_reg1)))));

Sd_reg1=St_g1_reg1-Sr_g1_reg1;
squares_Ok_g1_reg1=size((Sd_reg1(Sd_reg1>0)),2);
squares_N_g1_reg1=size((Sd_reg1(Sd_reg1<=0)),2);

Sd_reg1=St_r1_reg1-Sr_r1_reg1;
squares_Ok_r1_reg1=size((Sd_reg1(Sd_reg1>0)),2);
squares_N_r1_reg1=size((Sd_reg1(Sd_reg1<=0)),2);

tvv_g1_reg1=size((r2_g1_reg1(r2_g1_reg1>0.8)),2);
tv_g1_reg1=size((r2_g1_reg1(r2_g1_reg1<=0.8&r2_g1_reg1>0.5)),2);
t_g1_reg1=size((r2_g1_reg1(r2_g1_reg1<=0.5&r2_g1_reg1>0.25)),2);
tm_g1_reg1=size((r2_g1_reg1(r2_g1_reg1<=0.25)),2);

tvv_r1_reg1=size((r2_r1_reg1(r2_r1_reg1>0.8)),2);
tv_r1_reg1=size((r2_r1_reg1(r2_r1_reg1<=0.8&r2_r1_reg1>0.5)),2);
t_r1_reg1=size((r2_r1_reg1(r2_r1_reg1<=0.5&r2_r1_reg1>0.25)),2);
tm_r1_reg1=size((r2_r1_reg1(r2_r1_reg1<=0.25)),2);

p1_g1_OK_reg1=size((stats1_g_p1_reg1(stats1_g_p1_reg1<0.05)),2);
p1_g1_N_reg1=size((stats1_g_p1_reg1(stats1_g_p1_reg1>=0.05)),2);
p2_g1_OK_reg1=size((stats1_g_p2_reg1(stats1_g_p2_reg1<0.05)),2);
p2_g1_N_reg1=size((stats1_g_p2_reg1(stats1_g_p2_reg1>=0.05)),2);

p1_r1_OK_reg1=size((stats1_r_p1_reg1(stats1_r_p1_reg1<0.05)),2);
p1_r1_N_reg1=size((stats1_r_p1_reg1(stats1_r_p1_reg1>=0.05)),2);
p2_r1_OK_reg1=size((stats1_r_p2_reg1(stats1_r_p2_reg1<0.05)),2);
p2_r1_N_reg1=size((stats1_r_p2_reg1(stats1_r_p2_reg1>=0.05)),2);


stats_g_coeffcorr_reg1=abs(stats_g_coeffcorr_reg1);
stats_r_coeffcorr_reg1=abs(stats_r_coeffcorr_reg1);
corr_g1_OK_reg1=size(stats_g_coeffcorr_reg1(stats_g_coeffcorr_reg1<0.5),2);
corr_g1_N_reg1=size(stats_g_coeffcorr_reg1(stats_g_coeffcorr_reg1>=0.5),2);
corr_r1_OK_reg1=size(stats_r_coeffcorr_reg1(stats_r_coeffcorr_reg1<0.5),2);
corr_r1_N_reg1=size(stats_r_coeffcorr_reg1(stats_r_coeffcorr_reg1>=0.5),2);


results_reg1=[p1_g1_OK_reg1 p1_r1_OK_reg1;
    p1_g1_N_reg1 p1_r1_N_reg1;
    p2_g1_OK_reg1 p2_r1_OK_reg1;
    p2_g1_N_reg1 p2_r1_N_reg1;
    nan nan;
    corr_g1_OK_reg1 corr_r1_OK_reg1;
    corr_g1_N_reg1 corr_r1_N_reg1;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g1_reg1 squares_Ok_r1_reg1;
    squares_N_g1_reg1 squares_N_r1_reg1;
    nan nan;
    tvv_g1_reg1 tvv_r1_reg1;
    tv_g1_reg1 tv_r1_reg1;
    t_g1_reg1 t_r1_reg1
    tm_g1_reg1 tm_r1_reg1;
    nan nan;
    round(SD_before_reg1*1000)/1000 round(SD_before_reg1*1000)/1000;
    round(SD_after_g1_reg1*1000)/1000 round(SD_after_r1_reg1*1000)/1000];

end

if exist('opr_DIST_reg2','var')
[mp_reg2,np_reg2]=size(opr_DIST_reg2);
SD_before_reg2=sqrt(nansum(nansum((opr_DIST_reg2).*(opr_DIST_reg2)))/(mp_reg2*np_reg2-sum(sum(isnan(opr_DIST_reg2)))));
SD_after_g1_reg2=sqrt(nansum(nansum((opr_DIST_reg2-opr_DIST_est_g1_reg2).*(opr_DIST_reg2-opr_DIST_est_g1_reg2)))/(mp_reg2*np_reg2-sum(sum(isnan(opr_DIST_reg2)))));
SD_after_r1_reg2=sqrt(nansum(nansum((opr_DIST_reg2-opr_DIST_est_r1_reg2).*(opr_DIST_reg2-opr_DIST_est_r1_reg2)))/(mp_reg2*np_reg2-sum(sum(isnan(opr_DIST_reg2)))));

Sd_reg2=St_g1_reg2-Sr_g1_reg2;
squares_Ok_g1_reg2=size((Sd_reg2(Sd_reg2>0)),2);
squares_N_g1_reg2=size((Sd_reg2(Sd_reg2<=0)),2);

Sd_reg2=St_r1_reg2-Sr_r1_reg2;
squares_Ok_r1_reg2=size((Sd_reg2(Sd_reg2>0)),2);
squares_N_r1_reg2=size((Sd_reg2(Sd_reg2<=0)),2);

tvv_g1_reg2=size((r2_g1_reg2(r2_g1_reg2>0.8)),2);
tv_g1_reg2=size((r2_g1_reg2(r2_g1_reg2<=0.8&r2_g1_reg2>0.5)),2);
t_g1_reg2=size((r2_g1_reg2(r2_g1_reg2<=0.5&r2_g1_reg2>0.25)),2);
tm_g1_reg2=size((r2_g1_reg2(r2_g1_reg2<=0.25)),2);

tvv_r1_reg2=size((r2_r1_reg2(r2_r1_reg2>0.8)),2);
tv_r1_reg2=size((r2_r1_reg2(r2_r1_reg2<=0.8&r2_r1_reg2>0.5)),2);
t_r1_reg2=size((r2_r1_reg2(r2_r1_reg2<=0.5&r2_r1_reg2>0.25)),2);
tm_r1_reg2=size((r2_r1_reg2(r2_r1_reg2<=0.25)),2);

p1_g1_OK_reg2=size((stats1_g_p1_reg2(stats1_g_p1_reg2<0.05)),2);
p1_g1_N_reg2=size((stats1_g_p1_reg2(stats1_g_p1_reg2>=0.05)),2);
p2_g1_OK_reg2=size((stats1_g_p2_reg2(stats1_g_p2_reg2<0.05)),2);
p2_g1_N_reg2=size((stats1_g_p2_reg2(stats1_g_p2_reg2>=0.05)),2);

p1_r1_OK_reg2=size((stats1_r_p1_reg2(stats1_r_p1_reg2<0.05)),2);
p1_r1_N_reg2=size((stats1_r_p1_reg2(stats1_r_p1_reg2>=0.05)),2);
p2_r1_OK_reg2=size((stats1_r_p2_reg2(stats1_r_p2_reg2<0.05)),2);
p2_r1_N_reg2=size((stats1_r_p2_reg2(stats1_r_p2_reg2>=0.05)),2);


stats_g_coeffcorr_reg2=abs(stats_g_coeffcorr_reg2);
stats_r_coeffcorr_reg2=abs(stats_r_coeffcorr_reg2);
corr_g1_OK_reg2=size(stats_g_coeffcorr_reg2(stats_g_coeffcorr_reg2<0.5),2);
corr_g1_N_reg2=size(stats_g_coeffcorr_reg2(stats_g_coeffcorr_reg2>=0.5),2);
corr_r1_OK_reg2=size(stats_r_coeffcorr_reg2(stats_r_coeffcorr_reg2<0.5),2);
corr_r1_N_reg2=size(stats_r_coeffcorr_reg2(stats_r_coeffcorr_reg2>=0.5),2);


results_reg2=[p1_g1_OK_reg2 p1_r1_OK_reg2;
    p1_g1_N_reg2 p1_r1_N_reg2;
    p2_g1_OK_reg2 p2_r1_OK_reg2;
    p2_g1_N_reg2 p2_r1_N_reg2;
    nan nan;
    corr_g1_OK_reg2 corr_r1_OK_reg2;
    corr_g1_N_reg2 corr_r1_N_reg2;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g1_reg2 squares_Ok_r1_reg2;
    squares_N_g1_reg2 squares_N_r1_reg2;
    nan nan;
    tvv_g1_reg2 tvv_r1_reg2;
    tv_g1_reg2 tv_r1_reg2;
    t_g1_reg2 t_r1_reg2
    tm_g1_reg2 tm_r1_reg2;
    nan nan;
    round(SD_before_reg2*1000)/1000 round(SD_before_reg2*1000)/1000;
    round(SD_after_g1_reg2*1000)/1000 round(SD_after_r1_reg2*1000)/1000];


end

if exist('opr_DIST_reg3','var')
[mp_reg3,np_reg3]=size(opr_DIST_reg3);
SD_before_reg3=sqrt(nansum(nansum((opr_DIST_reg3).*(opr_DIST_reg3)))/(mp_reg3*np_reg3-sum(sum(isnan(opr_DIST_reg3)))));
SD_after_g1_reg3=sqrt(nansum(nansum((opr_DIST_reg3-opr_DIST_est_g1_reg3).*(opr_DIST_reg3-opr_DIST_est_g1_reg3)))/(mp_reg3*np_reg3-sum(sum(isnan(opr_DIST_reg3)))));
SD_after_r1_reg3=sqrt(nansum(nansum((opr_DIST_reg3-opr_DIST_est_r1_reg3).*(opr_DIST_reg3-opr_DIST_est_r1_reg3)))/(mp_reg3*np_reg3-sum(sum(isnan(opr_DIST_reg3)))));

Sd_reg3=St_g1_reg3-Sr_g1_reg3;
squares_Ok_g1_reg3=size((Sd_reg3(Sd_reg3>0)),2);
squares_N_g1_reg3=size((Sd_reg3(Sd_reg3<=0)),2);

Sd_reg3=St_r1_reg3-Sr_r1_reg3;
squares_Ok_r1_reg3=size((Sd_reg3(Sd_reg3>0)),2);
squares_N_r1_reg3=size((Sd_reg3(Sd_reg3<=0)),2);

tvv_g1_reg3=size((r2_g1_reg3(r2_g1_reg3>0.8)),2);
tv_g1_reg3=size((r2_g1_reg3(r2_g1_reg3<=0.8&r2_g1_reg3>0.5)),2);
t_g1_reg3=size((r2_g1_reg3(r2_g1_reg3<=0.5&r2_g1_reg3>0.25)),2);
tm_g1_reg3=size((r2_g1_reg3(r2_g1_reg3<=0.25)),2);

tvv_r1_reg3=size((r2_r1_reg3(r2_r1_reg3>0.8)),2);
tv_r1_reg3=size((r2_r1_reg3(r2_r1_reg3<=0.8&r2_r1_reg3>0.5)),2);
t_r1_reg3=size((r2_r1_reg3(r2_r1_reg3<=0.5&r2_r1_reg3>0.25)),2);
tm_r1_reg3=size((r2_r1_reg3(r2_r1_reg3<=0.25)),2);

p1_g1_OK_reg3=size((stats1_g_p1_reg3(stats1_g_p1_reg3<0.05)),2);
p1_g1_N_reg3=size((stats1_g_p1_reg3(stats1_g_p1_reg3>=0.05)),2);
p2_g1_OK_reg3=size((stats1_g_p2_reg3(stats1_g_p2_reg3<0.05)),2);
p2_g1_N_reg3=size((stats1_g_p2_reg3(stats1_g_p2_reg3>=0.05)),2);

p1_r1_OK_reg3=size((stats1_r_p1_reg3(stats1_r_p1_reg3<0.05)),2);
p1_r1_N_reg3=size((stats1_r_p1_reg3(stats1_r_p1_reg3>=0.05)),2);
p2_r1_OK_reg3=size((stats1_r_p2_reg3(stats1_r_p2_reg3<0.05)),2);
p2_r1_N_reg3=size((stats1_r_p2_reg3(stats1_r_p2_reg3>=0.05)),2);


stats_g_coeffcorr_reg3=abs(stats_g_coeffcorr_reg3);
stats_r_coeffcorr_reg3=abs(stats_r_coeffcorr_reg3);
corr_g1_OK_reg3=size(stats_g_coeffcorr_reg3(stats_g_coeffcorr_reg3<0.5),2);
corr_g1_N_reg3=size(stats_g_coeffcorr_reg3(stats_g_coeffcorr_reg3>=0.5),2);
corr_r1_OK_reg3=size(stats_r_coeffcorr_reg3(stats_r_coeffcorr_reg3<0.5),2);
corr_r1_N_reg3=size(stats_r_coeffcorr_reg3(stats_r_coeffcorr_reg3>=0.5),2);


results_reg3=[p1_g1_OK_reg3 p1_r1_OK_reg3;
    p1_g1_N_reg3 p1_r1_N_reg3;
    p2_g1_OK_reg3 p2_r1_OK_reg3;
    p2_g1_N_reg3 p2_r1_N_reg3;
    nan nan;
    corr_g1_OK_reg3 corr_r1_OK_reg3;
    corr_g1_N_reg3 corr_r1_N_reg3;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g1_reg3 squares_Ok_r1_reg3;
    squares_N_g1_reg3 squares_N_r1_reg3;
    nan nan;
    tvv_g1_reg3 tvv_r1_reg3;
    tv_g1_reg3 tv_r1_reg3;
    t_g1_reg3 t_r1_reg3
    tm_g1_reg3 tm_r1_reg3;
    nan nan;
    round(SD_before_reg3*1000)/1000 round(SD_before_reg3*1000)/1000;
    round(SD_after_g1_reg3*1000)/1000 round(SD_after_r1_reg3*1000)/1000];



end

if exist('opr_DIST_reg4','var')
[mp_reg4,np_reg4]=size(opr_DIST_reg4);
SD_before_reg4=sqrt(nansum(nansum((opr_DIST_reg4).*(opr_DIST_reg4)))/(mp_reg4*np_reg4-sum(sum(isnan(opr_DIST_reg4)))));
SD_after_g1_reg4=sqrt(nansum(nansum((opr_DIST_reg4-opr_DIST_est_g1_reg4).*(opr_DIST_reg4-opr_DIST_est_g1_reg4)))/(mp_reg4*np_reg4-sum(sum(isnan(opr_DIST_reg4)))));
SD_after_r1_reg4=sqrt(nansum(nansum((opr_DIST_reg4-opr_DIST_est_r1_reg4).*(opr_DIST_reg4-opr_DIST_est_r1_reg4)))/(mp_reg4*np_reg4-sum(sum(isnan(opr_DIST_reg4)))));

Sd_reg4=St_g1_reg4-Sr_g1_reg4;
squares_Ok_g1_reg4=size((Sd_reg4(Sd_reg4>0)),2);
squares_N_g1_reg4=size((Sd_reg4(Sd_reg4<=0)),2);

Sd_reg4=St_r1_reg4-Sr_r1_reg4;
squares_Ok_r1_reg4=size((Sd_reg4(Sd_reg4>0)),2);
squares_N_r1_reg4=size((Sd_reg4(Sd_reg4<=0)),2);

tvv_g1_reg4=size((r2_g1_reg4(r2_g1_reg4>0.8)),2);
tv_g1_reg4=size((r2_g1_reg4(r2_g1_reg4<=0.8&r2_g1_reg4>0.5)),2);
t_g1_reg4=size((r2_g1_reg4(r2_g1_reg4<=0.5&r2_g1_reg4>0.25)),2);
tm_g1_reg4=size((r2_g1_reg4(r2_g1_reg4<=0.25)),2);

tvv_r1_reg4=size((r2_r1_reg4(r2_r1_reg4>0.8)),2);
tv_r1_reg4=size((r2_r1_reg4(r2_r1_reg4<=0.8&r2_r1_reg4>0.5)),2);
t_r1_reg4=size((r2_r1_reg4(r2_r1_reg4<=0.5&r2_r1_reg4>0.25)),2);
tm_r1_reg4=size((r2_r1_reg4(r2_r1_reg4<=0.25)),2);

p1_g1_OK_reg4=size((stats1_g_p1_reg4(stats1_g_p1_reg4<0.05)),2);
p1_g1_N_reg4=size((stats1_g_p1_reg4(stats1_g_p1_reg4>=0.05)),2);
p2_g1_OK_reg4=size((stats1_g_p2_reg4(stats1_g_p2_reg4<0.05)),2);
p2_g1_N_reg4=size((stats1_g_p2_reg4(stats1_g_p2_reg4>=0.05)),2);

p1_r1_OK_reg4=size((stats1_r_p1_reg4(stats1_r_p1_reg4<0.05)),2);
p1_r1_N_reg4=size((stats1_r_p1_reg4(stats1_r_p1_reg4>=0.05)),2);
p2_r1_OK_reg4=size((stats1_r_p2_reg4(stats1_r_p2_reg4<0.05)),2);
p2_r1_N_reg4=size((stats1_r_p2_reg4(stats1_r_p2_reg4>=0.05)),2);


stats_g_coeffcorr_reg4=abs(stats_g_coeffcorr_reg4);
stats_r_coeffcorr_reg4=abs(stats_r_coeffcorr_reg4);
corr_g1_OK_reg4=size(stats_g_coeffcorr_reg4(stats_g_coeffcorr_reg4<0.5),2);
corr_g1_N_reg4=size(stats_g_coeffcorr_reg4(stats_g_coeffcorr_reg4>=0.5),2);
corr_r1_OK_reg4=size(stats_r_coeffcorr_reg4(stats_r_coeffcorr_reg4<0.5),2);
corr_r1_N_reg4=size(stats_r_coeffcorr_reg4(stats_r_coeffcorr_reg4>=0.5),2);


results_reg4=[p1_g1_OK_reg4 p1_r1_OK_reg4;
    p1_g1_N_reg4 p1_r1_N_reg4;
    p2_g1_OK_reg4 p2_r1_OK_reg4;
    p2_g1_N_reg4 p2_r1_N_reg4;
    nan nan;
    corr_g1_OK_reg4 corr_r1_OK_reg4;
    corr_g1_N_reg4 corr_r1_N_reg4;
    nan nan; nan nan;nan nan;nan nan;nan nan;
    squares_Ok_g1_reg4 squares_Ok_r1_reg4;
    squares_N_g1_reg4 squares_N_r1_reg4;
    nan nan;
    tvv_g1_reg4 tvv_r1_reg4;
    tv_g1_reg4 tv_r1_reg4;
    t_g1_reg4 t_r1_reg4
    tm_g1_reg4 tm_r1_reg4;
    nan nan;
    round(SD_before_reg4*1000)/1000 round(SD_before_reg4*1000)/1000;
    round(SD_after_g1_reg4*1000)/1000 round(SD_after_r1_reg4*1000)/1000];

end



results=[SD_before;SD_after_r1;squares_Ok_r1;squares_S_r1;...
    squares_N_r1;(iz2-iz1+1)*(jz2-jz1+1)];

blok1=cell((iz2-iz1+1)*(jz2-jz1+1),20);

blok1(1,1) = {'Model 2 (opr_DIST=b1+b2*DISTl)'};
blok1(1,3) = {'glmfit'};
blok1(2,2:20) = {'a','b','se_a','se_b','p_a','p_b','corr12',...
    'min resid. [m]','max resid.[m]','mean resid.[m]','median resid.[m]',...
    '','i','j','','Sr [m2]','St [m2]','Sy [m2]','r2'};

blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),1)=num2cell((1:1:(iz2-iz1+1)*...
    (jz2-jz1+1))');
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),2:3)=num2cell(round(beta_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),4:5)=num2cell(round(se_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),6:7)=num2cell(round(p_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),8)=num2cell(round(corr_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),9:12)=num2cell(round(stat_resid_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),14)=num2cell(I(1:((iz2-iz1+1)*...
    (jz2-jz1+1)),1));
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),15)=num2cell(J(1:((iz2-iz1+1)*...
    (jz2-jz1+1)),1));

blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),17)=num2cell(round(Sr_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),18)=num2cell(round(St_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),19)=num2cell(round(Sy_g1*1000)/1000);
blok1(3:((iz2-iz1+1)*(jz2-jz1+1)+2),20)=num2cell(round(r2_g1*1000)/1000);

blok2=cell((iz2-iz1+1)*(jz2-jz1+1)+2,20);

blok2(1,1) = {'Model 2 (opr_DIST=b1+b2*DISTl)'};
blok2(1,3) = {'robusfit'};
blok2(2,2:20) = {'a','b','se_a','se_b','p_a','p_b','corr12',...
    'min resid. [m]','max resid.[m]','mean resid.[m]','median resid.[m]',...
    '','i','j','','Sr [m2]','St [m2]','Sy [m2]','r2'};

blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),1)=num2cell((1:1:(iz2-iz1+1)*...
    (jz2-jz1+1))');
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),2:3)=num2cell(round(beta_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),4:5)=num2cell(round(se_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),6:7)=num2cell(round(p_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),8)=num2cell(round(corr_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),9:12)=num2cell(round(stat_resid_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),14)=num2cell(I(1:((iz2-iz1+1)*...
    (jz2-jz1+1)),1));
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),15)=num2cell(J(1:((iz2-iz1+1)*...
    (jz2-jz1+1)),1));

blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),17)=num2cell(round(Sr_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),18)=num2cell(round(St_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),19)=num2cell(round(Sy_r1*1000)/1000);
blok2(3:((iz2-iz1+1)*(jz2-jz1+1)+2),20)=num2cell(round(r2_r1*1000)/1000);




blok8=cell(28,11);

blok8(1,1)={'Results summary'};
blok8(2,2:11)={'Total','Total','Region 1','Region 1','Region 2','Region 2',...
    'Region 3','Region 3','Region 4','Region 4'};
blok8(3,2:11)={'glmfit','robustfit','glmfit','robustfit','glmfit',...
    'robustfit','glmfit','robustfit','glmfit','robustfit'};
blok8(4,1)={'count of pixel with p_a < 0.05'};
blok8(5,1)={'count of pixel with p_a > 0.05'};
blok8(6,1)={'count of pixel with p_b < 0.05'};
blok8(7,1)={'count of pixel with p_b > 0.05'};

blok8(9:10,1)={'correlation between a,b < 0.5','correlation between a,b > 0.5'};

blok8(12:14,1)={'max resid. [m]','mean resid. [m]','median resid. [m]'};

blok8(16:29,1)={'count of pixel with St > Sr','count of pixel with St < Sr',...
    '','count of pixel with r2 > 0,80','count of pixel with 0,50 < r2 < 0,80'...
    ,'count of pixel with 0,25 < r2 < 0,50','count of pixel with r2 < 0,25',...
    '','distance SD before calibration [m]',...
    'distance SD after calibration [m]','','conf. treshold T [%]',...
    'count of measurement with confidence > T','count of measurement with confidence < T'};
blok8(4,2)=num2cell(p1_g1_OK);
blok8(5,2)=num2cell(p1_g1_N);
blok8(6,2)=num2cell(p2_g1_OK);
blok8(7,2)=num2cell(p2_g1_N);
blok8(9:10,2)=[num2cell(corr_g1_OK),num2cell(corr_g1_N)];

blok8(4,3)=num2cell(p1_r1_OK);
blok8(5,3)=num2cell(p1_r1_N);
blok8(6,3)=num2cell(p2_r1_OK);
blok8(7,3)=num2cell(p2_r1_N);
blok8(9:10,3)=[num2cell(corr_r1_OK),num2cell(corr_r1_N)];

blok8(12,2)=num2cell(round(max(stat_resid_g1(:,2))*1000)/1000);
blok8(13,2)=num2cell(round(nanmean(stat_resid_g1(:,3))*1000)/1000);
blok8(14,2)=num2cell(round(nanmedian(stat_resid_g1(:,4))*1000)/1000);

blok8(12,3)=num2cell(round(max(stat_resid_r1(:,2))*1000)/1000);
blok8(13,3)=num2cell(round(nanmean(stat_resid_r1(:,3))*1000)/1000);
blok8(14,3)=num2cell(round(nanmedian(stat_resid_r1(:,4))*1000)/1000);

blok8(16,2:3)=[num2cell(squares_Ok_g1+squares_S_g1),num2cell(squares_Ok_r1+squares_S_r1)];
blok8(17,2:3)=[num2cell(squares_N_g1),num2cell(squares_N_r1)];

blok8(19,2:3)=[num2cell(tvv_g1),num2cell(tvv_r1)];
blok8(20,2:3)=[num2cell(tv_g1),num2cell(tv_r1)];
blok8(21,2:3)=[num2cell(t_g1),num2cell(t_r1)];
blok8(22,2:3)=[num2cell(tm_g1),num2cell(tm_r1)];

blok8(24,2:3)=[num2cell(round(SD_before*1000)/1000),num2cell(round(SD_before*1000)/1000)];
blok8(25,2:3)=[num2cell(round(SD_after_g1*1000)/1000),num2cell(round(SD_after_r1*1000)/1000)];

blok8(27,2)=num2cell(CONF_treshold);
blok8(28,2:3)=[num2cell(c_OK),num2cell(c_OK)];
blok8(29,2:3)=[num2cell(c_N),num2cell(c_N)];

if exist('results_reg1','var')
    blok8(4:25,4:5)=num2cell(results_reg1);
end

if exist('results_reg2','var')
    blok8(4:25,6:7)=num2cell(results_reg2);
end

if exist('results_reg3','var')
    blok8(4:25,8:9)=num2cell(results_reg3);
end

if exist('results_reg4','var')
    blok8(4:25,10:11)=num2cell(results_reg4);
end


excelFileName='Regrese_Model2.xls';

xlswrite(excelFileName, blok1,'GLMFIT');
xlswrite(excelFileName, blok2,'ROBUSTFIT');
xlswrite(excelFileName, blok8,'OVERVIEW');


delete_default_sheet(excelFileName)

end

